@@ -41,5 +41,6 @@ def only(*names: str):
 
 
 if __name__ != "__main__":
-    import hygiene  # type: ignore
+    import hygiene
+
     hygiene.cleanup()
